@@ -1,5 +1,6 @@
 from inspire_info.Author import Author
 import datetime
+import os
 
 class Publication(object):
 
@@ -10,11 +11,12 @@ class Publication(object):
         self.created = publication["created"]
         self.updated = publication["updated"]
 
-        self.authors = self.meta["authors"]
+        self.authors = self.meta.get("authors", [])
         self.author_objects = [Author(author) for author in self.authors]
         self.author_names = [auth.full_name for auth in self.author_objects]
         self.author_uuids = [auth.uuid for auth in self.author_objects]
         self.author_bais = [auth.bai for auth in self.author_objects]
+
         self.id = publication["id"]
         self.earliest_date = self.meta["earliest_date"]
         self.title = self.meta["titles"][0]["title"]
@@ -23,6 +25,11 @@ class Publication(object):
 
         datetime_object = datetime.datetime.strptime(self.earliest_date, '%Y')
         self.earliest_date_year = datetime_object.year
+        if "collaborations" in self.meta:
+            self.collaborations = [item["value"] for item in self.meta["collaborations"]]
+        else:
+            self.collaborations = []
+        self.matched = False
 
     def __repr__(self):
         return "Publication(" + self.title + ")"
@@ -33,3 +40,11 @@ class Publication(object):
             return [item["value"].lower() for item in self.meta["keywords"]]
         else:
             return None
+
+    def downloaded_file(self, link_type="bibtex"):
+        return os.path.split(self.links[link_type])[-1]
+
+    @property
+    def downloaded_bibtex_file(self):
+        return self.downloaded_file(link_type="bibtex")
+
